import { adapter } from '@/utils';
import {
  adapterOfMqttAuthList,
  adapterOfMqttPastureEnumList,
  adapterOfMqttPastureList,
  adapterOfMqttTopicList,
  adapterOfMqttUserList
} from '@/service/api/mqtt.adapter';
import { backgroundRequest } from '../request';

/** 获取用户鉴权列表 */
export const fetchMqttAuthList = async (page: number, pageSize: number, topic: string) => {
  const data = await backgroundRequest.post<Mqtt.Auth[] | null>(
    '/mqtt/auth/list',
    { topic },
    { headers: { page, page_size: pageSize } }
  );
  return adapter(adapterOfMqttAuthList, data);
};

/** 删除用户鉴权列表 */
export const mqttAuthDelete = (authId: number) => {
  return backgroundRequest.delete<ApiBoolean.OK | null>(`/mqtt/auth/delete/${authId}`);
};

/** 添加用户鉴权列表 */
export const mqttAuthAdd = (params: Mqtt.Auth) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/auth/add', params);
};

/** 编辑用户鉴权列表 */
export const mqttAuthEdit = (param: Mqtt.Auth) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/auth/edit', param);
};

/** 获取topic列表 */
export const fetchMqttTopicList = async (page: number, pageSize: number, topic_name: string) => {
  const data = await backgroundRequest.post<Mqtt.Topic[] | null>(
    '/mqtt/topic/list',
    { topic_name },
    { headers: { page, page_size: pageSize } }
  );
  return adapter(adapterOfMqttTopicList, data);
};

/** 添加topic */
export const mqttTopicAdd = (params: Mqtt.Topic) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic/add', params);
};

/** 编辑topic */
export const mqttTopicEdit = (param: Mqtt.Topic) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/topic/edit', param);
};

export const mqttTopicDelete = (authId: number) => {
  return backgroundRequest.delete<ApiBoolean.OK | null>(`/mqtt/topic/delete/${authId}`);
};

/** 获取用户列表 */
export const fetchMqttUserList = async (page: number, pageSize: number, name: string) => {
  const data = await backgroundRequest.post<Mqtt.User[] | null>(
    '/mqtt/user/list',
    { name },
    { headers: { page, page_size: pageSize } }
  );
  return adapter(adapterOfMqttUserList, data);
};

/** 添加User */
export const mqttUserAdd = (params: Mqtt.User) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/user/add', params);
};

/** 编辑User */
export const mqttUserEdit = (param: Mqtt.User) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/user/edit', param);
};

/** 获取牧场列表 */
export const fetchMqttPastureList = async (page: number, pageSize: number, name: string) => {
  const data = await backgroundRequest.post<Mqtt.Pasture[] | null>(
    '/mqtt/pasture/list',
    { name },
    { headers: { page, page_size: pageSize } }
  );
  return adapter(adapterOfMqttPastureList, data);
};

/** 添加牧场 */
export const mqttPastureAdd = (params: Mqtt.Pasture) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/pasture/add', params);
};

/** 编辑牧场 */
export const mqttPastureEdit = (param: Mqtt.Pasture) => {
  return backgroundRequest.post<ApiBoolean.OK | null>('/mqtt/pasture/edit', param);
};

export const pastureEnumList = async () => {
  const data = await backgroundRequest.post<Common.OptionWithKey<any>[] | null>('/mqtt/pasture/enum/list');
  return adapter(adapterOfMqttPastureEnumList, data);
};
